==> getitdone-0.0.3.tar.gz: getitdone-0.0.3/README.md <==
[![PyPI Version][pypi-image]][pypi-url]
[![Build Status][build-image]][build-url]
[![Code Coverage][coverage-image]][coverage-url]
[![Python Versions][python versions badge]][python]
[![Last Commit][commit badge]][commit]
[![License][license badge]][license]

<!-- Links -->
[codecov]: https://codecov.io/gh/proper-testing/proper
[commit]: https://github.com/proper-testing/proper/commit/HEAD
[python]: https://www.python.org/
[license]: LICENSE
[release]: https://github.com/ryanleonbutler/getitdone/releases/latest
[github]: https://github.com/ryanleonbutler/getitdone

<!-- Badges -->
[pypi-image]: https://img.shields.io/pypi/v/getitdone
[pypi-url]: https://pypi.org/project/getitdone/
[build-image]: https://github.com/ryanleonbutler/getitdone/actions/workflows/build.yml/badge.svg
[build-url]: https://github.com/nalgeon/getitdone-py/actions/workflows/build.yml
[coverage-image]: https://codecov.io/gh/ryanleonbutler/getitdone/branch/master/graph/badge.svg?token=4CQG41WFF4
[coverage-url]: https://codecov.io/gh/ryanleonbutler/getitdone
[codecov badge]: https://codecov.io/gh/proper-testing/proper/branch/master/graph/badge.svg
[commit badge]: https://img.shields.io/github/last-commit/ryanleonbutler/getitdone
[python versions badge]: https://shields.io/pypi/pyversions/getitdone
[license badge]: https://img.shields.io/pypi/l/getitdone
[release badge]: https://img.shields.io/github/v/release/ryanleonbutler/getitdone
[github badge]: https://github.com/proper-testing/proper/workflows/CI/badge.svg


# getitdone

### About
Command line to-do list application.

I was browsing on the Internet and wanted a really basic todo list application, which was free and opensource. Since I am in the process of learning more about software development I decided to create my own.


### Installation
```
$ pip install getitdone
```

### Uninstall
```
$ pip uninstall getitdone
```

### Usage
![](https://github.com/ryanleonbutler/getitdone/blob/master/images/image1.jpg?raw=true)



### User Manual
    OPTIONS
        --new or -n '<task-name>'
            Create a new task with name in first argument
        --update or -u '<task-name>' '<new-name>'
            Update task in first argument with value second argument
        --delete or -d '<task-name>'
            Delete task in first argument with value second argument
        --list or -l
            List all tasks
        --help or -h
            Shows man page for todolist

### Report an issue
Create an issue on GitHub with as much supporting information and detail about the bug or issue as possible.

### Contribute
Anyone is welcome to contribute to the project. You can submit your pull request and the changes will be reviewed. When submitting changes, ensure your code is "Pythonic". Use only Stand Library modules. No module are allowed that need further installation.

### License
Licensing is AGPL by default but an MIT license is available for purchase.

### Credits
Duanne Mattheus - Thank you fo providing the name for the application.

==> getitdone-0.0.5.tar.gz: getitdone-0.0.5/README.md <==
[![PyPI Version][pypi-image]][pypi-url]
[![Tests Status][tests-image]][tests-url]
[![Code Coverage][coverage-image]][coverage-url]
[![Last Commit][commit badge]][commit]

<!-- Links -->
[pypi-url]: https://pypi.org/project/getitdone/
[tests-url]: https://github.com/ryanleonbutler/getitdone/actions/workflows/tests.yml
[coverage-url]: https://codecov.io/gh/ryanleonbutler/getitdone
[commit]: https://github.com/ryanleonbutler/getitdone/commit/HEAD

<!-- Badges -->
[pypi-image]: https://img.shields.io/pypi/v/getitdone
[tests-image]: https://github.com/ryanleonbutler/getitdone/actions/workflows/tests.yml/badge.svg
[coverage-image]: https://codecov.io/gh/ryanleonbutler/getitdone/branch/master/graph/badge.svg?token=4CQG41WFF4
[commit badge]: https://img.shields.io/github/last-commit/ryanleonbutler/getitdone


# getitdone

### About
**getitdone** command line to-do list app... now let's make some lists!

I was browsing on the Internet and wanted a really basic todo list application, which was free and opensource. Since I am in the process of learning more about software development I decided to create my own.


### Installation
```
$ pip install getitdone
```

### Uninstall
```
$ pip uninstall getitdone
```

### Usage
![](https://github.com/ryanleonbutler/getitdone/blob/master/images/image1.jpg?raw=true)



### User Manual
    OPTIONS
        --new or -n '<task-name>'
            Create a new task with name in first argument
        --update or -u '<task-name>' '<new-name>'
            Update task in first argument with value second argument
        --delete or -d '<task-name>'
            Delete task in first argument with value second argument
        --list or -l
            List all tasks
        --help or -h
            Shows man page for todolist

### Report an issue
Create an issue on GitHub with as much supporting information and detail about the bug or issue as possible.

### Contribute
Anyone is welcome to contribute to the project. You can submit your pull request and the changes will be reviewed. When submitting changes, ensure your code is "Pythonic". Use only Stand Library modules. No module are allowed that need further installation.

### License
Licensing is AGPL.

### Credits
Duanne Mattheus - Thank you for providing the name for the application.
